@@ -1,5 +1,5 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2009 Michael Howitz
+# Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
 
 from icemac.addressbook.i18n import MessageFactory as _
@@ -165,6 +165,10 @@ class BaseEditFormWithCancel(BaseEditForm):
         self.status = self.noChangesMessage
 
 
+class GroupEditForm(z3c.form.group.GroupForm, BaseEditForm):
+    "BaseEditForm as group form."
+
+
 class BaseDeleteForm(BaseEditForm):
     "Display a deletion confirmation dialog."
 
